# Omnitils
Universal reusable Python utilities for the modern human. I got tired of constantly iterating on and re-writing the same common functionality
and design practices spread across various Python projects, so I decided to combine and curate a collection of utilities I've written
over the years into a single module.

## ❓ What's in it?
Mostly pretty straightforward utilities for dealing with files, schemas, properties, requests, and a variety of other common 
needs of the modern Python user. Nothing in here is going to be novel earth-shattering stuff, you can find dozens of Stackoverflow
entries using some of the same methodologies, apart from a handful of opinionated approaches I've taken in certain cases.

The bulk of these utilities are things beginner or intermediate Python programmers already have in their toolbelt and can easily write.
However, if you develop a lot of apps and are tired of taking valuable time to reimplement the same solution to common problems, many of
these may be helpful.

## 💌 How can I support your projects?
If you find this module useful, or any of my other apps (Proxyshop, MTG Art Downloader, Hexproof API, Scalecord, etc) feel free to subscribe 
to my [Patreon here](https://patreon.com/mpcfill). It comes with a few nice perks, and you'd be giving me the means to spend more time working on these
awesome apps! If you'd like to support, but Patreon isn't your thing, feel free to buy me a coffee [via Paypal](https://www.paypal.com/donate/?hosted_button_id=D96NBC6ZAJ8H6). 
Thanks so much to all my amazing supporters! 🚀
